@@ -1131,7 +1131,7 @@ parse_delim <- function(x){
 # Is the EDI Data Repository accessible?
 #
 ping_edi <- function() {
-  r <- httr::GET(url = "https://pasta.lternet.edu/package/eml/edi/759") # Warn if EDI is down
+  r <- httr::RETRY("GET", url = "https://pasta.lternet.edu/package/eml/edi/759") # Warn if EDI is down
   if (httr::status_code(r) != 200) {
     stop("The EDI Repository is down for regular maintenance (Wednesday 01:00",
          " - 03:00 UTC). If you have reached this message outside maintenance",
